Requirements:

  - >=python-efl-1.14.0
  - PyPDF2
  - pyxdg

Install:

  From pypi:
  (sudo) pip install Lekha

  Manually:
  (sudo) python setup.py install


![screenshot](https://www.enlightenment.org/ss/e-55511fafe962b5.69067897.jpg "Screenshot")
